#
# spec file for package python-venusian
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2013-2019 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-venusian
Version:        3.1.1
Release:        1.1
Summary:        A library for deferring decorator actions
License:        SUSE-Repoze AND ZPL-2.1
URL:            https://github.com/Pylons/venusian
Source:         https://files.pythonhosted.org/packages/source/v/venusian/venusian-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sphinxcontrib-copybutton}
# /SECTION
# SECTION documentation requirements
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module pylons-sphinx-themes}
# /SECTION
%python_subpackages

%description
Venusian is a library which allows framework authors to defer
decorator actions.  Instead of taking actions when a function (or
class) decorator is executed at import time, you can defer the action
usually taken by the decorator until a separate "scan" phase.

See the "docs" directory of the package or the online documentation at
http://docs.pylonsproject.org/projects/venusian/dev/.

%package doc
Summary:        Documentation for %{name}
Requires:       %{name} = %{version}

%description doc
This package contains documentation files for %{name}.

%prep
%autosetup -p1 -n venusian-%{version}

rm -rf venusian.*-info
sed -i '/addopts/d' setup.cfg

%build
%pyproject_wheel
PYTHONPATH=src python%python_bin_suffix -msphinx docs build/sphinx/html \
    && rm -rv build/sphinx/html/{.buildinfo,objects.inv,.doctrees}

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst README.rst
%{python_sitelib}/venusian
%{python_sitelib}/venusian-%{version}.dist-info

%files %{python_files doc}
%license LICENSE.txt
%doc build/sphinx/html/

%changelog
* Thu Jan 16 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 3.1.1
  * Add support for Python 3.13.
  * Fix GitHub test actions.
- Drop py313.patch, merged upstream
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- add py313.patch to fix tests with python 3.13
* Wed Jan 24 2024 ecsos <ecsos@opensuse.org>
- Fix build error in Leap.
  Use correct BuildRequires.
* Wed Jan 10 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.1.0:
  * Remove support for Python 3.5 and 3.6
  * Add support for Python 3.9, 3.10, 3.11 and 3.12.
- Drop patch fix-pylons-sphinx-theme.diff
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add missing %%{?sle15_python_module_pythons}
* Tue May 23 2023 Matej Cepl <mcepl@suse.com>
- Don't use sphinx-build and clean up the SPEC file.
* Mon Aug 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to pytest and remove not needed extra buildrequires
* Tue Mar 10 2020 pgajdos@suse.com
- version update to 3.0.0
  3.0.0 (2019-10-04)
  - This release matches 2.0.0 other than in the version number. This fixes an
    issue with Requires-Python metadata not being uploaded correctly to PyPi.
    This version is only compatible with Python 3.5+
  2.0.0 (2019-10-04)
  - Drop support for Python 2.7, 3.3, and 3.4
  - Removed the usage of the ``imp`` module to squelch the warnings regarding a
    deprecated modules. See https://github.com/Pylons/venusian/pull/63 and
    https://github.com/Pylons/venusian/issues/57
- modified patches
  %% fix-pylons-sphinx-theme.diff (refreshed)
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Thu Feb  7 2019 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 1.2.0 (2019-01-08)
  + Add support for Python 3.7.
  + Drop support for Python 3.3.
- Combine package-doc and package spec
- add fix-pylons-sphinx-theme.diff patch
  to generate docs with the pylons-sphinx-themes package
* Thu Jun 28 2018 mcepl@suse.com
- Clean up SPEC file
- Enable tests and make docs work again
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Fri Jul 14 2017 aloisio@gmx.com
- Update to version 1.1.0
  * Updated to using py.test instead of nosetest, and added
    support for Python 3.4 -> 3.6
  * Make scanning more resilient of metaclasses that return
    proxies for any attribute access.
  * Fix bug where using the same venusian decorator on both a
    class and its methods would cause the method decorations to be
    ignored. See https://github.com/Pylons/venusian/issues/40
  * Drop support for Python 2.6.
  * Drop support for Python 3.2: it is no longer supported by
    current packaging / CI tools.
  * Support loaders that require the module name as argument to
    their get_filename() method. This fixes problems with zipped
    packages on Python 3.
  * Micro-optimization when ignores are used (see
    https://github.com/Pylons/venusian/pull/20).
  * A tox run now combines coverage between Py2 and Py3.
- Split docs and tests into separate package to make the
  latter work
- Converted to single-spec
* Fri Feb  6 2015 hpj@urpla.net
- update to version 1.0
  - Fix an issue under PyPy > 2.0 where attached decorators may not be found.
  - Drop support of Python 2.4 / 2.5 / Jython.
  - Add lift and onlyliftedfrom class decorators to allow for inheritance of
    venusian decorators attached to superclass methods. See the API
    documentation for more information.
  - Fix bug where otherwise undecorated subclass of a superclass that had
    venusian decorators on it would inherit its superclass' decorations.
    Venusian decorators should have never been inherited implicitly. See
    https://github.com/Pylons/venusian/issues/11#issuecomment-4977352
* Wed Dec 18 2013 cfarrell@suse.com
- license update: SUSE-Repoze
  See LICENSE
* Tue Dec 10 2013 p.drouand@gmail.com
- Use tarball from pypi.python.org/ as source
* Tue Dec 10 2013 p.drouand@gmail.com
- Change license to get it SPDX compliant;
  In general, python packages are licensed under BSD derived; the
  most closed license is BSD-2-Clause
* Mon Jul 29 2013 speilicke@suse.com
- Simplify macro usage
* Sun Jul 28 2013 hpj@urpla.net
- version 1.0a8: initial release
